# data-ingestion-infrastructure
Contains automation modules to create data ingestion pipelines. Data ingestion pipelines are defined in [sumup/data-ingestion-framework](https://github.com/sumup/data-ingestion-framework) repo.
